@@ -6,7 +6,7 @@ use crate::half_life::HALF_LIFE          ;
  use crate::nuclide::nucleons_nuclide    ;
  use crate::nuclide::Nuclide             ;
  use crate::particle::Particle           ;
-// use crate::nuclide::rand                ;
+
 
  use crate::particle::PROTONMASS         ; 
  use crate::particle::NEUTRONMASS        ; 
@@ -20,7 +20,6 @@ use Pion::lepton::Lepton;
 use Pion::lepton::AntiLepton;
 use Pion::baryon::Baryon;
 use Pion::baryon::AntiBaryon;
-//use crate::particle::Party;
 
  fn rand()->u64{
    let mut x: u64 = 0;
@@ -547,14 +546,7 @@ match x {
   }
   (total_energy, particlevec)
  }
- /*
- theorectical nuclide using the liquid drop model
-                                   &str amu, binding energy,  likely decay mode
- fn create(proton: usize, neutron: usize)->(f64,f64){
-    
- }
  
-*/
 }
 
 
