@@ -28,9 +28,6 @@ pub const ELECTRON_AFFINITY : [f64;118] = [
        
  ];
  
- 
- //function mullikan electro  
- 
     
  
  // (Single, double, triple)    
@@ -103,19 +100,34 @@ pub const ELECTRON_AFFINITY : [f64;118] = [
       
      
 ];
-
 /*
-const IONIC_RADII : [f64;118] = [
+Rahm, M., Hoffmann, R., & Ashcroft, N. W. (2016). Atomic and Ionic Radii of Elements 1-96. Chemistry - A European Journal, 22(41), 14625–14632. doi:10.1002/chem.201602949
+*/
 
+pub const IONIC_RADII : [f64;118] = [
 
+ 1.54E-10 , 1.34E-10 , 2.20E-10 , 2.19E-10 , 2.05E-10 , 1.90E-10 ,
+ 1.79E-10 , 1.71E-10 , 1.63E-10 , 1.56E-10 , 2.25E-10 , 2.40E-10 ,//Mg
+ 2.39E-10 , 2.32E-10 , 2.23E-10 , 2.14E-10 , 2.06E-10 , 1.97E-10 ,//Ar
+ 2.34E-10 , 2.70E-10 , 2.63E-10 , 2.57E-10 , 2.52E-10 , 2.33E-10 ,//Cr
+ 2.42E-10 , 2.26E-10 , 2.22E-10 , 2.19E-10 , 2.17E-10 , 2.22E-10 ,//Zn
+ 2.33E-10 , 2.34E-10 , 2.31E-10 , 2.24E-10 , 2.19E-10 , 2.12E-10 ,//Kr   
+ 2.40E-10 , 2.79E-10 , 2.74E-10 , 2.68E-10 , 2.51E-10 , 2.44E-10 ,//Mo
+ 2.41E-10 , 2.37E-10 , 2.33E-10 , 2.15E-10 , 2.25E-10 , 2.38E-10 ,//Cd
+ 2.46E-10 , 2.48E-10 , 2.46E-10 , 2.42E-10 , 2.38E-10 , 2.32E-10 ,//Xe
+ 2.49E-10 , 2.93E-10 , 2.84E-10 , 2.82E-10 , 2.86E-10 , 2.84E-10 ,//Nd
+ 2.83E-10 , 2.80E-10 , 2.80E-10 , 2.77E-10 , 2.76E-10 , 2.75E-10 ,//Dy
+ 2.73E-10 , 2.72E-10 , 2.71E-10 , 2.77E-10 , 2.70E-10 , 2.64E-10 ,//Hf
+ 2.58E-10 , 2.53E-10 , 2.49E-10 , 2.44E-10 , 2.33E-10 , 2.30E-10 ,//Pt
+ 2.26E-10 , 2.29E-10 , 2.42E-10 , 2.49E-10 , 2.50E-10 , 2.50E-10 ,//Po
+ 2.47E-10 , 2.43E-10 , 2.58E-10 , 2.92E-10 , 2.93E-10 , 2.89E-10 ,//Th
+ 2.85E-10 , 2.83E-10 , 2.80E-10 , 2.78E-10 , 2.76E-10 , 2.64E-10 ,//Cm
+ f64::NAN , f64::NAN , f64::NAN , f64::NAN , f64::NAN , f64::NAN , 
+ f64::NAN , f64::NAN , f64::NAN , f64::NAN , f64::NAN , f64::NAN ,
+ f64::NAN , f64::NAN , f64::NAN , f64::NAN , f64::NAN , f64::NAN ,
+ f64::NAN , f64::NAN , f64::NAN , f64::NAN ,
 
-
-
-
-
-
-
-]*/
+];
 
 
 
